# Icons
unplug by tezar tantular from [Noun Project](https://thenounproject.com/browse/icons/term/unplug/) (CC BY 3.0)

skull from [Font Awesome Free](https://fontawesome.com/icons/skull?f=classic&s=solid) (CC BY 4.0)